@@ -130,8 +130,8 @@ sigma2 <- var(theta) / 10
 ## Put in default priors
     if(is.null(prior.mean.beta)) prior.mean.beta <- rep(0, p)
     if(is.null(prior.var.beta)) prior.var.beta <- rep(1000, p)
-    if(is.null(prior.tau2)) prior.tau2 <- c(0.001, 0.001)    
-    if(is.null(prior.sigma2)) prior.sigma2 <- c(0.001, 0.001)
+    if(is.null(prior.tau2)) prior.tau2 <- c(1, 0.01)    
+    if(is.null(prior.sigma2)) prior.sigma2 <- c(1, 0.01)
      
      
 ## Checks    
@@ -227,7 +227,7 @@ sigma2.posterior.shape <- prior.sigma2[1] + 0.5 * n
     if(sum(is.na(W))>0) stop("W has missing 'NA' values.", call.=FALSE)
     if(!is.numeric(W)) stop("W has non-numeric values.", call.=FALSE)
     if(min(W)<0) stop("W has negative elements.", call.=FALSE)
-    if(sum(W!=t(W))>0) stop("W is not symmetric.", call.=FALSE)
+    if(!is.symmetric.matrix(W)) stop("W is not symmetric.", call.=FALSE)
     if(min(apply(W, 1, sum))==0) stop("W has some areas with no neighbours (one of the row sums equals zero).", call.=FALSE)    
 
 ## Create the triplet object
@@ -266,7 +266,7 @@ temp <- 1
 ## Start timer
      if(verbose)
      {
-     cat("Collecting", n.sample, "samples\n", sep = " ")
+         cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
      progressBar <- txtProgressBar(style = 3)
      percentage.points<-round((1:100/100)*n.sample)
      }else
